Class: TerminalShop::Models::CardCollectResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/terminal_shop/models/card_collect_response.rb,
sig/terminal_shop/models/card_collect_response.rbs

Overview

See Also:

  • TerminalShop::Models::CardCollectResponse#data

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(url:) ⇒ Data

Some parameter documentations has been truncated, see TerminalShop::Models::CardCollectResponse::Data for more details.

URL for collecting card information.

Parameters:

  • url (String)

    Temporary URL that allows a user to enter credit card details over https at term

  • url: (String)


# File 'lib/terminal_shop/models/card_collect_response.rb', line 25

Instance Attribute Details

#urlString

Temporary URL that allows a user to enter credit card details over https at terminal.shop.

Parameters:

  • value (String)

Returns:

  • (String)


23
# File 'lib/terminal_shop/models/card_collect_response.rb', line 23

required :url, String

Instance Method Details

#to_hash{ url: String }

Returns:

  • ({ url: String })


22
# File 'sig/terminal_shop/models/card_collect_response.rbs', line 22

def to_hash: -> { url: String }