Class: TerminalShop::Models::OrderAPI::Item

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/terminal_shop/models/order.rb,
sig/terminal_shop/models/order.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



87
# File 'sig/terminal_shop/models/order.rbs', line 87

def initialize: (

Instance Attribute Details

#amountInteger

Amount of the item in the order, in cents (USD).

Parameters:

  • value (Integer)

Returns:

  • (Integer)


101
# File 'lib/terminal_shop/models/order.rb', line 101

required :amount, Integer

#descriptionString?

Description of the item in the order.

Parameters:

  • (String)

Returns:

  • (String, nil)


113
# File 'lib/terminal_shop/models/order.rb', line 113

optional :description, String

#idString

Unique object identifier. The format and length of IDs may change over time.

Parameters:

  • value (String)

Returns:

  • (String)


95
# File 'lib/terminal_shop/models/order.rb', line 95

required :id, String

#product_variant_idString?

ID of the product variant of the item in the order.

Parameters:

  • (String)

Returns:

  • (String, nil)


119
# File 'lib/terminal_shop/models/order.rb', line 119

optional :product_variant_id, String, api_name: :productVariantID

#quantityInteger

Quantity of the item in the order.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


107
# File 'lib/terminal_shop/models/order.rb', line 107

required :quantity, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


95
# File 'sig/terminal_shop/models/order.rbs', line 95

def to_hash: -> {